==> django-postcode-lookup-0.4.0.tar.gz: django-postcode-lookup-0.4.0/src/django_postcode_lookup/views.py <==
from django.core.exceptions import ImproperlyConfigured
from rest_framework.authentication import CSRFCheck
from rest_framework.exceptions import PermissionDenied
from rest_framework.response import Response
from rest_framework.views import APIView

from django_postcode_lookup import loading, serializers
from django_postcode_lookup.backends.base import PostcodeLookupException


class PostcodeLookupView(APIView):
    authentication_classes = ()
    serializer_class = serializers.PostcodeLookupSerializer
    backend = loading.get_backend()

    def post(self, request, format=None):
        """
        Usage::

            POST /checkout/address-lookup
            {
                'postcode': X,
                'number': Y,
            }

        Returns::

            {
              "data": {
                "city": "UTRECHT",
                "street": "Ravellaan",
                "number": "16,
                "postcode": "3533JN",
              }
            }


        """
        if not self.backend:
            raise ImproperlyConfigured("No backend is defined")

        self._enforce_csrf(request)

        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)

        try:
            result = self.backend.lookup(
                postcode=serializer.data['postcode'],
                number=serializer.data['number'])
        except PostcodeLookupException:
            return Response({
                'error': 'No valid response received from backend'
            },
            status=400)
        return Response(result.json())

    def get_serializer(self, **kwargs):
        return self.serializer_class(
            backend=self.backend, **kwargs)

    def _enforce_csrf(self, request):
        """Make sure that we have a valid CSRF token.

        Django restframework does validate this when using the
        SessionAuthentication but since that also checks if the user is
        authenticated we can't really use that

        """
        reason = CSRFCheck().process_view(request, None, (), {})
        if reason:
            # CSRF failed, bail with explicit error message
            raise PermissionDenied('CSRF Failed: %s' % reason)

==> django-postcode-lookup-1.0.1.tar.gz: django-postcode-lookup-1.0.1/src/django_postcode_lookup/views.py <==
from django.core.exceptions import ImproperlyConfigured
from django.utils.decorators import method_decorator
from django.views.decorators.csrf import csrf_protect
from rest_framework import status
from rest_framework.response import Response
from rest_framework.views import APIView

from django_postcode_lookup import loading, serializers
from django_postcode_lookup.backends.base import PostcodeLookupException


class PostcodeLookupView(APIView):
    authentication_classes = ()
    serializer_class = serializers.PostcodeLookupSerializer
    backend = loading.get_backend()

    @method_decorator(csrf_protect)
    def dispatch(self, request, *args, **kwargs):
        """Add csrf validation to this endpoint without authentication."""
        return super().dispatch(request, *args, **kwargs)

    def post(self, request):
        """
        Usage::

            POST /checkout/address-lookup
            {
                'postcode': X,
                'number': Y,
            }

        Returns::

            {
              "data": {
                "city": "UTRECHT",
                "street": "Ravellaan",
                "number": "16,
                "postcode": "3533JN",
              }
            }


        """
        if not self.backend:
            raise ImproperlyConfigured("No backend is defined")

        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)

        try:
            result = self.backend.lookup(
                postcode=serializer.data['postcode'],
                number=serializer.data['number'])
        except PostcodeLookupException:
            return Response(
                {
                    'error': 'No valid response received from backend'
                },
                status=status.HTTP_400_BAD_REQUEST
            )

        return Response(result.json())

    def get_serializer(self, **kwargs):
        return self.serializer_class(
            backend=self.backend, **kwargs)
